#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContentRiskDetail(object):

    def __init__(self):
        self._code = None
        self._ext_properties = None
        self._generated_file = None
        self._name = None
        self._notice = None
        self._origin_file = None
        self._risk_infos = None
        self._risk_level = None
        self._type = None
        self._viola_words = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def ext_properties(self):
        return self._ext_properties

    @ext_properties.setter
    def ext_properties(self, value):
        self._ext_properties = value
    @property
    def generated_file(self):
        return self._generated_file

    @generated_file.setter
    def generated_file(self, value):
        self._generated_file = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def notice(self):
        return self._notice

    @notice.setter
    def notice(self, value):
        self._notice = value
    @property
    def origin_file(self):
        return self._origin_file

    @origin_file.setter
    def origin_file(self, value):
        self._origin_file = value
    @property
    def risk_infos(self):
        return self._risk_infos

    @risk_infos.setter
    def risk_infos(self, value):
        self._risk_infos = value
    @property
    def risk_level(self):
        return self._risk_level

    @risk_level.setter
    def risk_level(self, value):
        self._risk_level = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def viola_words(self):
        return self._viola_words

    @viola_words.setter
    def viola_words(self, value):
        self._viola_words = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.ext_properties:
            if hasattr(self.ext_properties, 'to_alipay_dict'):
                params['ext_properties'] = self.ext_properties.to_alipay_dict()
            else:
                params['ext_properties'] = self.ext_properties
        if self.generated_file:
            if hasattr(self.generated_file, 'to_alipay_dict'):
                params['generated_file'] = self.generated_file.to_alipay_dict()
            else:
                params['generated_file'] = self.generated_file
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.notice:
            if hasattr(self.notice, 'to_alipay_dict'):
                params['notice'] = self.notice.to_alipay_dict()
            else:
                params['notice'] = self.notice
        if self.origin_file:
            if hasattr(self.origin_file, 'to_alipay_dict'):
                params['origin_file'] = self.origin_file.to_alipay_dict()
            else:
                params['origin_file'] = self.origin_file
        if self.risk_infos:
            if hasattr(self.risk_infos, 'to_alipay_dict'):
                params['risk_infos'] = self.risk_infos.to_alipay_dict()
            else:
                params['risk_infos'] = self.risk_infos
        if self.risk_level:
            if hasattr(self.risk_level, 'to_alipay_dict'):
                params['risk_level'] = self.risk_level.to_alipay_dict()
            else:
                params['risk_level'] = self.risk_level
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.viola_words:
            if hasattr(self.viola_words, 'to_alipay_dict'):
                params['viola_words'] = self.viola_words.to_alipay_dict()
            else:
                params['viola_words'] = self.viola_words
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContentRiskDetail()
        if 'code' in d:
            o.code = d['code']
        if 'ext_properties' in d:
            o.ext_properties = d['ext_properties']
        if 'generated_file' in d:
            o.generated_file = d['generated_file']
        if 'name' in d:
            o.name = d['name']
        if 'notice' in d:
            o.notice = d['notice']
        if 'origin_file' in d:
            o.origin_file = d['origin_file']
        if 'risk_infos' in d:
            o.risk_infos = d['risk_infos']
        if 'risk_level' in d:
            o.risk_level = d['risk_level']
        if 'type' in d:
            o.type = d['type']
        if 'viola_words' in d:
            o.viola_words = d['viola_words']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContactFollower(object):

    def __init__(self):
        self._avatar = None
        self._default_avatar = None
        self._each_record_flag = None
        self._user_id = None

    @property
    def avatar(self):
        return self._avatar

    @avatar.setter
    def avatar(self, value):
        self._avatar = value
    @property
    def default_avatar(self):
        return self._default_avatar

    @default_avatar.setter
    def default_avatar(self, value):
        self._default_avatar = value
    @property
    def each_record_flag(self):
        return self._each_record_flag

    @each_record_flag.setter
    def each_record_flag(self, value):
        self._each_record_flag = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.avatar:
            if hasattr(self.avatar, 'to_alipay_dict'):
                params['avatar'] = self.avatar.to_alipay_dict()
            else:
                params['avatar'] = self.avatar
        if self.default_avatar:
            if hasattr(self.default_avatar, 'to_alipay_dict'):
                params['default_avatar'] = self.default_avatar.to_alipay_dict()
            else:
                params['default_avatar'] = self.default_avatar
        if self.each_record_flag:
            if hasattr(self.each_record_flag, 'to_alipay_dict'):
                params['each_record_flag'] = self.each_record_flag.to_alipay_dict()
            else:
                params['each_record_flag'] = self.each_record_flag
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContactFollower()
        if 'avatar' in d:
            o.avatar = d['avatar']
        if 'default_avatar' in d:
            o.default_avatar = d['default_avatar']
        if 'each_record_flag' in d:
            o.each_record_flag = d['each_record_flag']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceAntdataassetsPublishtaskCreateModel(object):

    def __init__(self):
        self._guid = None

    @property
    def guid(self):
        return self._guid

    @guid.setter
    def guid(self, value):
        self._guid = value


    def to_alipay_dict(self):
        params = dict()
        if self.guid:
            if hasattr(self.guid, 'to_alipay_dict'):
                params['guid'] = self.guid.to_alipay_dict()
            else:
                params['guid'] = self.guid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceAntdataassetsPublishtaskCreateModel()
        if 'guid' in d:
            o.guid = d['guid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TipsDelivery import TipsDelivery


class AlipayOpenMiniTipsDeliveryBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniTipsDeliveryBatchqueryResponse, self).__init__()
        self._tips_delivery_list = None
        self._total_pages = None
        self._total_size = None

    @property
    def tips_delivery_list(self):
        return self._tips_delivery_list

    @tips_delivery_list.setter
    def tips_delivery_list(self, value):
        if isinstance(value, list):
            self._tips_delivery_list = list()
            for i in value:
                if isinstance(i, TipsDelivery):
                    self._tips_delivery_list.append(i)
                else:
                    self._tips_delivery_list.append(TipsDelivery.from_alipay_dict(i))
    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniTipsDeliveryBatchqueryResponse, self).parse_response_content(response_content)
        if 'tips_delivery_list' in response:
            self.tips_delivery_list = response['tips_delivery_list']
        if 'total_pages' in response:
            self.total_pages = response['total_pages']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopRecommendInfo(object):

    def __init__(self):
        self._recommend = None
        self._recommend_address = None
        self._recommend_latitude = None
        self._recommend_longtitude = None
        self._recommend_name = None
        self._unconfidence_reason = None

    @property
    def recommend(self):
        return self._recommend

    @recommend.setter
    def recommend(self, value):
        self._recommend = value
    @property
    def recommend_address(self):
        return self._recommend_address

    @recommend_address.setter
    def recommend_address(self, value):
        self._recommend_address = value
    @property
    def recommend_latitude(self):
        return self._recommend_latitude

    @recommend_latitude.setter
    def recommend_latitude(self, value):
        self._recommend_latitude = value
    @property
    def recommend_longtitude(self):
        return self._recommend_longtitude

    @recommend_longtitude.setter
    def recommend_longtitude(self, value):
        self._recommend_longtitude = value
    @property
    def recommend_name(self):
        return self._recommend_name

    @recommend_name.setter
    def recommend_name(self, value):
        self._recommend_name = value
    @property
    def unconfidence_reason(self):
        return self._unconfidence_reason

    @unconfidence_reason.setter
    def unconfidence_reason(self, value):
        self._unconfidence_reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.recommend:
            if hasattr(self.recommend, 'to_alipay_dict'):
                params['recommend'] = self.recommend.to_alipay_dict()
            else:
                params['recommend'] = self.recommend
        if self.recommend_address:
            if hasattr(self.recommend_address, 'to_alipay_dict'):
                params['recommend_address'] = self.recommend_address.to_alipay_dict()
            else:
                params['recommend_address'] = self.recommend_address
        if self.recommend_latitude:
            if hasattr(self.recommend_latitude, 'to_alipay_dict'):
                params['recommend_latitude'] = self.recommend_latitude.to_alipay_dict()
            else:
                params['recommend_latitude'] = self.recommend_latitude
        if self.recommend_longtitude:
            if hasattr(self.recommend_longtitude, 'to_alipay_dict'):
                params['recommend_longtitude'] = self.recommend_longtitude.to_alipay_dict()
            else:
                params['recommend_longtitude'] = self.recommend_longtitude
        if self.recommend_name:
            if hasattr(self.recommend_name, 'to_alipay_dict'):
                params['recommend_name'] = self.recommend_name.to_alipay_dict()
            else:
                params['recommend_name'] = self.recommend_name
        if self.unconfidence_reason:
            if hasattr(self.unconfidence_reason, 'to_alipay_dict'):
                params['unconfidence_reason'] = self.unconfidence_reason.to_alipay_dict()
            else:
                params['unconfidence_reason'] = self.unconfidence_reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopRecommendInfo()
        if 'recommend' in d:
            o.recommend = d['recommend']
        if 'recommend_address' in d:
            o.recommend_address = d['recommend_address']
        if 'recommend_latitude' in d:
            o.recommend_latitude = d['recommend_latitude']
        if 'recommend_longtitude' in d:
            o.recommend_longtitude = d['recommend_longtitude']
        if 'recommend_name' in d:
            o.recommend_name = d['recommend_name']
        if 'unconfidence_reason' in d:
            o.unconfidence_reason = d['unconfidence_reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OpenCertifyIdentityParam import OpenCertifyIdentityParam
from alipay.aop.api.domain.OpenCertifyMerchantConfig import OpenCertifyMerchantConfig


class AlipayUserCertifyOpenInitializeModel(object):

    def __init__(self):
        self._biz_code = None
        self._face_contrast_picture = None
        self._identity_param = None
        self._merchant_config = None
        self._outer_order_no = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def face_contrast_picture(self):
        return self._face_contrast_picture

    @face_contrast_picture.setter
    def face_contrast_picture(self, value):
        self._face_contrast_picture = value
    @property
    def identity_param(self):
        return self._identity_param

    @identity_param.setter
    def identity_param(self, value):
        if isinstance(value, OpenCertifyIdentityParam):
            self._identity_param = value
        else:
            self._identity_param = OpenCertifyIdentityParam.from_alipay_dict(value)
    @property
    def merchant_config(self):
        return self._merchant_config

    @merchant_config.setter
    def merchant_config(self, value):
        if isinstance(value, OpenCertifyMerchantConfig):
            self._merchant_config = value
        else:
            self._merchant_config = OpenCertifyMerchantConfig.from_alipay_dict(value)
    @property
    def outer_order_no(self):
        return self._outer_order_no

    @outer_order_no.setter
    def outer_order_no(self, value):
        self._outer_order_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.face_contrast_picture:
            if hasattr(self.face_contrast_picture, 'to_alipay_dict'):
                params['face_contrast_picture'] = self.face_contrast_picture.to_alipay_dict()
            else:
                params['face_contrast_picture'] = self.face_contrast_picture
        if self.identity_param:
            if hasattr(self.identity_param, 'to_alipay_dict'):
                params['identity_param'] = self.identity_param.to_alipay_dict()
            else:
                params['identity_param'] = self.identity_param
        if self.merchant_config:
            if hasattr(self.merchant_config, 'to_alipay_dict'):
                params['merchant_config'] = self.merchant_config.to_alipay_dict()
            else:
                params['merchant_config'] = self.merchant_config
        if self.outer_order_no:
            if hasattr(self.outer_order_no, 'to_alipay_dict'):
                params['outer_order_no'] = self.outer_order_no.to_alipay_dict()
            else:
                params['outer_order_no'] = self.outer_order_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertifyOpenInitializeModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'face_contrast_picture' in d:
            o.face_contrast_picture = d['face_contrast_picture']
        if 'identity_param' in d:
            o.identity_param = d['identity_param']
        if 'merchant_config' in d:
            o.merchant_config = d['merchant_config']
        if 'outer_order_no' in d:
            o.outer_order_no = d['outer_order_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTravelGoodsSyncresultQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelGoodsSyncresultQueryResponse, self).__init__()
        self._goods_biz_status = None
        self._sync_failed_code = None
        self._sync_failed_msg = None
        self._sync_status = None

    @property
    def goods_biz_status(self):
        return self._goods_biz_status

    @goods_biz_status.setter
    def goods_biz_status(self, value):
        self._goods_biz_status = value
    @property
    def sync_failed_code(self):
        return self._sync_failed_code

    @sync_failed_code.setter
    def sync_failed_code(self, value):
        self._sync_failed_code = value
    @property
    def sync_failed_msg(self):
        return self._sync_failed_msg

    @sync_failed_msg.setter
    def sync_failed_msg(self, value):
        self._sync_failed_msg = value
    @property
    def sync_status(self):
        return self._sync_status

    @sync_status.setter
    def sync_status(self, value):
        self._sync_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelGoodsSyncresultQueryResponse, self).parse_response_content(response_content)
        if 'goods_biz_status' in response:
            self.goods_biz_status = response['goods_biz_status']
        if 'sync_failed_code' in response:
            self.sync_failed_code = response['sync_failed_code']
        if 'sync_failed_msg' in response:
            self.sync_failed_msg = response['sync_failed_msg']
        if 'sync_status' in response:
            self.sync_status = response['sync_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScanDetail(object):

    def __init__(self):
        self._scan_report = None
        self._scan_state = None
        self._scan_type = None

    @property
    def scan_report(self):
        return self._scan_report

    @scan_report.setter
    def scan_report(self, value):
        self._scan_report = value
    @property
    def scan_state(self):
        return self._scan_state

    @scan_state.setter
    def scan_state(self, value):
        self._scan_state = value
    @property
    def scan_type(self):
        return self._scan_type

    @scan_type.setter
    def scan_type(self, value):
        self._scan_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.scan_report:
            if hasattr(self.scan_report, 'to_alipay_dict'):
                params['scan_report'] = self.scan_report.to_alipay_dict()
            else:
                params['scan_report'] = self.scan_report
        if self.scan_state:
            if hasattr(self.scan_state, 'to_alipay_dict'):
                params['scan_state'] = self.scan_state.to_alipay_dict()
            else:
                params['scan_state'] = self.scan_state
        if self.scan_type:
            if hasattr(self.scan_type, 'to_alipay_dict'):
                params['scan_type'] = self.scan_type.to_alipay_dict()
            else:
                params['scan_type'] = self.scan_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScanDetail()
        if 'scan_report' in d:
            o.scan_report = d['scan_report']
        if 'scan_state' in d:
            o.scan_state = d['scan_state']
        if 'scan_type' in d:
            o.scan_type = d['scan_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ApeSelect import ApeSelect


class AlipayDigitalopUcdpApeselectSyncModel(object):

    def __init__(self):
        self._project_id = None
        self._select_list = None

    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def select_list(self):
        return self._select_list

    @select_list.setter
    def select_list(self, value):
        if isinstance(value, ApeSelect):
            self._select_list = value
        else:
            self._select_list = ApeSelect.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.select_list:
            if hasattr(self.select_list, 'to_alipay_dict'):
                params['select_list'] = self.select_list.to_alipay_dict()
            else:
                params['select_list'] = self.select_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDigitalopUcdpApeselectSyncModel()
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'select_list' in d:
            o.select_list = d['select_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExtendParamsDTO(object):

    def __init__(self):
        self._card_type = None
        self._hb_fq_num = None
        self._hb_fq_seller_percent = None
        self._industry_reflux_info = None
        self._specified_seller_name = None
        self._sys_service_provider_id = None

    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def hb_fq_num(self):
        return self._hb_fq_num

    @hb_fq_num.setter
    def hb_fq_num(self, value):
        self._hb_fq_num = value
    @property
    def hb_fq_seller_percent(self):
        return self._hb_fq_seller_percent

    @hb_fq_seller_percent.setter
    def hb_fq_seller_percent(self, value):
        self._hb_fq_seller_percent = value
    @property
    def industry_reflux_info(self):
        return self._industry_reflux_info

    @industry_reflux_info.setter
    def industry_reflux_info(self, value):
        self._industry_reflux_info = value
    @property
    def specified_seller_name(self):
        return self._specified_seller_name

    @specified_seller_name.setter
    def specified_seller_name(self, value):
        self._specified_seller_name = value
    @property
    def sys_service_provider_id(self):
        return self._sys_service_provider_id

    @sys_service_provider_id.setter
    def sys_service_provider_id(self, value):
        self._sys_service_provider_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.hb_fq_num:
            if hasattr(self.hb_fq_num, 'to_alipay_dict'):
                params['hb_fq_num'] = self.hb_fq_num.to_alipay_dict()
            else:
                params['hb_fq_num'] = self.hb_fq_num
        if self.hb_fq_seller_percent:
            if hasattr(self.hb_fq_seller_percent, 'to_alipay_dict'):
                params['hb_fq_seller_percent'] = self.hb_fq_seller_percent.to_alipay_dict()
            else:
                params['hb_fq_seller_percent'] = self.hb_fq_seller_percent
        if self.industry_reflux_info:
            if hasattr(self.industry_reflux_info, 'to_alipay_dict'):
                params['industry_reflux_info'] = self.industry_reflux_info.to_alipay_dict()
            else:
                params['industry_reflux_info'] = self.industry_reflux_info
        if self.specified_seller_name:
            if hasattr(self.specified_seller_name, 'to_alipay_dict'):
                params['specified_seller_name'] = self.specified_seller_name.to_alipay_dict()
            else:
                params['specified_seller_name'] = self.specified_seller_name
        if self.sys_service_provider_id:
            if hasattr(self.sys_service_provider_id, 'to_alipay_dict'):
                params['sys_service_provider_id'] = self.sys_service_provider_id.to_alipay_dict()
            else:
                params['sys_service_provider_id'] = self.sys_service_provider_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExtendParamsDTO()
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'hb_fq_num' in d:
            o.hb_fq_num = d['hb_fq_num']
        if 'hb_fq_seller_percent' in d:
            o.hb_fq_seller_percent = d['hb_fq_seller_percent']
        if 'industry_reflux_info' in d:
            o.industry_reflux_info = d['industry_reflux_info']
        if 'specified_seller_name' in d:
            o.specified_seller_name = d['specified_seller_name']
        if 'sys_service_provider_id' in d:
            o.sys_service_provider_id = d['sys_service_provider_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FinAttachment import FinAttachment


class AnttechBlockchainFinanceTrusplePersoncreditinquirySubmitModel(object):

    def __init__(self):
        self._attachments = None
        self._cert_no = None
        self._cert_type = None
        self._customer_name = None
        self._external_product_code = None
        self._external_user_id = None
        self._inquiry_reason = None
        self._inquiry_template = None
        self._inst_code = None
        self._request_id = None

    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, list):
            self._attachments = list()
            for i in value:
                if isinstance(i, FinAttachment):
                    self._attachments.append(i)
                else:
                    self._attachments.append(FinAttachment.from_alipay_dict(i))
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def customer_name(self):
        return self._customer_name

    @customer_name.setter
    def customer_name(self, value):
        self._customer_name = value
    @property
    def external_product_code(self):
        return self._external_product_code

    @external_product_code.setter
    def external_product_code(self, value):
        self._external_product_code = value
    @property
    def external_user_id(self):
        return self._external_user_id

    @external_user_id.setter
    def external_user_id(self, value):
        self._external_user_id = value
    @property
    def inquiry_reason(self):
        return self._inquiry_reason

    @inquiry_reason.setter
    def inquiry_reason(self, value):
        self._inquiry_reason = value
    @property
    def inquiry_template(self):
        return self._inquiry_template

    @inquiry_template.setter
    def inquiry_template(self, value):
        self._inquiry_template = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.attachments:
            if isinstance(self.attachments, list):
                for i in range(0, len(self.attachments)):
                    element = self.attachments[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachments[i] = element.to_alipay_dict()
            if hasattr(self.attachments, 'to_alipay_dict'):
                params['attachments'] = self.attachments.to_alipay_dict()
            else:
                params['attachments'] = self.attachments
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.customer_name:
            if hasattr(self.customer_name, 'to_alipay_dict'):
                params['customer_name'] = self.customer_name.to_alipay_dict()
            else:
                params['customer_name'] = self.customer_name
        if self.external_product_code:
            if hasattr(self.external_product_code, 'to_alipay_dict'):
                params['external_product_code'] = self.external_product_code.to_alipay_dict()
            else:
                params['external_product_code'] = self.external_product_code
        if self.external_user_id:
            if hasattr(self.external_user_id, 'to_alipay_dict'):
                params['external_user_id'] = self.external_user_id.to_alipay_dict()
            else:
                params['external_user_id'] = self.external_user_id
        if self.inquiry_reason:
            if hasattr(self.inquiry_reason, 'to_alipay_dict'):
                params['inquiry_reason'] = self.inquiry_reason.to_alipay_dict()
            else:
                params['inquiry_reason'] = self.inquiry_reason
        if self.inquiry_template:
            if hasattr(self.inquiry_template, 'to_alipay_dict'):
                params['inquiry_template'] = self.inquiry_template.to_alipay_dict()
            else:
                params['inquiry_template'] = self.inquiry_template
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTrusplePersoncreditinquirySubmitModel()
        if 'attachments' in d:
            o.attachments = d['attachments']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'customer_name' in d:
            o.customer_name = d['customer_name']
        if 'external_product_code' in d:
            o.external_product_code = d['external_product_code']
        if 'external_user_id' in d:
            o.external_user_id = d['external_user_id']
        if 'inquiry_reason' in d:
            o.inquiry_reason = d['inquiry_reason']
        if 'inquiry_template' in d:
            o.inquiry_template = d['inquiry_template']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherSendGuideInfo import VoucherSendGuideInfo
from alipay.aop.api.domain.VoucherUseGuideInfo import VoucherUseGuideInfo


class VoucherCustomerGuideInfo(object):

    def __init__(self):
        self._voucher_send_guide_info = None
        self._voucher_use_guide_info = None

    @property
    def voucher_send_guide_info(self):
        return self._voucher_send_guide_info

    @voucher_send_guide_info.setter
    def voucher_send_guide_info(self, value):
        if isinstance(value, VoucherSendGuideInfo):
            self._voucher_send_guide_info = value
        else:
            self._voucher_send_guide_info = VoucherSendGuideInfo.from_alipay_dict(value)
    @property
    def voucher_use_guide_info(self):
        return self._voucher_use_guide_info

    @voucher_use_guide_info.setter
    def voucher_use_guide_info(self, value):
        if isinstance(value, VoucherUseGuideInfo):
            self._voucher_use_guide_info = value
        else:
            self._voucher_use_guide_info = VoucherUseGuideInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.voucher_send_guide_info:
            if hasattr(self.voucher_send_guide_info, 'to_alipay_dict'):
                params['voucher_send_guide_info'] = self.voucher_send_guide_info.to_alipay_dict()
            else:
                params['voucher_send_guide_info'] = self.voucher_send_guide_info
        if self.voucher_use_guide_info:
            if hasattr(self.voucher_use_guide_info, 'to_alipay_dict'):
                params['voucher_use_guide_info'] = self.voucher_use_guide_info.to_alipay_dict()
            else:
                params['voucher_use_guide_info'] = self.voucher_use_guide_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherCustomerGuideInfo()
        if 'voucher_send_guide_info' in d:
            o.voucher_send_guide_info = d['voucher_send_guide_info']
        if 'voucher_use_guide_info' in d:
            o.voucher_use_guide_info = d['voucher_use_guide_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenSpBlueseaactivityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSpBlueseaactivityQueryResponse, self).__init__()
        self._address = None
        self._biz_scene = None
        self._business_lic = None
        self._city_code = None
        self._district_code = None
        self._food_business_lic = None
        self._food_circulate_lic = None
        self._food_health_lic = None
        self._food_production_lic = None
        self._food_service_lic = None
        self._indoor_pic = None
        self._memo = None
        self._merchant_logon = None
        self._province_code = None
        self._shop_entrance_pic = None
        self._status = None
        self._sub_merchant_id = None
        self._tobacco_lic = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def business_lic(self):
        return self._business_lic

    @business_lic.setter
    def business_lic(self, value):
        self._business_lic = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def food_business_lic(self):
        return self._food_business_lic

    @food_business_lic.setter
    def food_business_lic(self, value):
        self._food_business_lic = value
    @property
    def food_circulate_lic(self):
        return self._food_circulate_lic

    @food_circulate_lic.setter
    def food_circulate_lic(self, value):
        self._food_circulate_lic = value
    @property
    def food_health_lic(self):
        return self._food_health_lic

    @food_health_lic.setter
    def food_health_lic(self, value):
        self._food_health_lic = value
    @property
    def food_production_lic(self):
        return self._food_production_lic

    @food_production_lic.setter
    def food_production_lic(self, value):
        self._food_production_lic = value
    @property
    def food_service_lic(self):
        return self._food_service_lic

    @food_service_lic.setter
    def food_service_lic(self, value):
        self._food_service_lic = value
    @property
    def indoor_pic(self):
        return self._indoor_pic

    @indoor_pic.setter
    def indoor_pic(self, value):
        self._indoor_pic = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_logon(self):
        return self._merchant_logon

    @merchant_logon.setter
    def merchant_logon(self, value):
        self._merchant_logon = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def shop_entrance_pic(self):
        return self._shop_entrance_pic

    @shop_entrance_pic.setter
    def shop_entrance_pic(self, value):
        self._shop_entrance_pic = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value
    @property
    def tobacco_lic(self):
        return self._tobacco_lic

    @tobacco_lic.setter
    def tobacco_lic(self, value):
        self._tobacco_lic = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSpBlueseaactivityQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'business_lic' in response:
            self.business_lic = response['business_lic']
        if 'city_code' in response:
            self.city_code = response['city_code']
        if 'district_code' in response:
            self.district_code = response['district_code']
        if 'food_business_lic' in response:
            self.food_business_lic = response['food_business_lic']
        if 'food_circulate_lic' in response:
            self.food_circulate_lic = response['food_circulate_lic']
        if 'food_health_lic' in response:
            self.food_health_lic = response['food_health_lic']
        if 'food_production_lic' in response:
            self.food_production_lic = response['food_production_lic']
        if 'food_service_lic' in response:
            self.food_service_lic = response['food_service_lic']
        if 'indoor_pic' in response:
            self.indoor_pic = response['indoor_pic']
        if 'memo' in response:
            self.memo = response['memo']
        if 'merchant_logon' in response:
            self.merchant_logon = response['merchant_logon']
        if 'province_code' in response:
            self.province_code = response['province_code']
        if 'shop_entrance_pic' in response:
            self.shop_entrance_pic = response['shop_entrance_pic']
        if 'status' in response:
            self.status = response['status']
        if 'sub_merchant_id' in response:
            self.sub_merchant_id = response['sub_merchant_id']
        if 'tobacco_lic' in response:
            self.tobacco_lic = response['tobacco_lic']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenAppOperatorVo import OpenAppOperatorVo


class AlipayOpenMiniInnerMembersQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerMembersQueryResponse, self).__init__()
        self._open_app_operator_vo = None

    @property
    def open_app_operator_vo(self):
        return self._open_app_operator_vo

    @open_app_operator_vo.setter
    def open_app_operator_vo(self, value):
        if isinstance(value, list):
            self._open_app_operator_vo = list()
            for i in value:
                if isinstance(i, OpenAppOperatorVo):
                    self._open_app_operator_vo.append(i)
                else:
                    self._open_app_operator_vo.append(OpenAppOperatorVo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerMembersQueryResponse, self).parse_response_content(response_content)
        if 'open_app_operator_vo' in response:
            self.open_app_operator_vo = response['open_app_operator_vo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerJobworthAdapterQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerJobworthAdapterQueryResponse, self).__init__()
        self._adapter_score = None
        self._sub_code = None
        self._sub_msg = None
        self._url = None

    @property
    def adapter_score(self):
        return self._adapter_score

    @adapter_score.setter
    def adapter_score(self, value):
        self._adapter_score = value
    @property
    def sub_code(self):
        return self._sub_code

    @sub_code.setter
    def sub_code(self, value):
        self._sub_code = value
    @property
    def sub_msg(self):
        return self._sub_msg

    @sub_msg.setter
    def sub_msg(self, value):
        self._sub_msg = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerJobworthAdapterQueryResponse, self).parse_response_content(response_content)
        if 'adapter_score' in response:
            self.adapter_score = response['adapter_score']
        if 'sub_code' in response:
            self.sub_code = response['sub_code']
        if 'sub_msg' in response:
            self.sub_msg = response['sub_msg']
        if 'url' in response:
            self.url = response['url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncApbillCustviewBatchqueryModel(object):

    def __init__(self):
        self._ar_no = None
        self._bill_invoice_link_statuses = None
        self._bill_types = None
        self._biz_type = None
        self._ccy = None
        self._end_month = None
        self._inst_id = None
        self._invoice_type = None
        self._ip_role_id = None
        self._page_no = None
        self._page_size = None
        self._pay_statuses = None
        self._pd_codes = None
        self._price_id = None
        self._price_policy_id = None
        self._settle_type = None
        self._start_month = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def bill_invoice_link_statuses(self):
        return self._bill_invoice_link_statuses

    @bill_invoice_link_statuses.setter
    def bill_invoice_link_statuses(self, value):
        if isinstance(value, list):
            self._bill_invoice_link_statuses = list()
            for i in value:
                self._bill_invoice_link_statuses.append(i)
    @property
    def bill_types(self):
        return self._bill_types

    @bill_types.setter
    def bill_types(self, value):
        if isinstance(value, list):
            self._bill_types = list()
            for i in value:
                self._bill_types.append(i)
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def ccy(self):
        return self._ccy

    @ccy.setter
    def ccy(self, value):
        self._ccy = value
    @property
    def end_month(self):
        return self._end_month

    @end_month.setter
    def end_month(self, value):
        self._end_month = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def pay_statuses(self):
        return self._pay_statuses

    @pay_statuses.setter
    def pay_statuses(self, value):
        if isinstance(value, list):
            self._pay_statuses = list()
            for i in value:
                self._pay_statuses.append(i)
    @property
    def pd_codes(self):
        return self._pd_codes

    @pd_codes.setter
    def pd_codes(self, value):
        if isinstance(value, list):
            self._pd_codes = list()
            for i in value:
                self._pd_codes.append(i)
    @property
    def price_id(self):
        return self._price_id

    @price_id.setter
    def price_id(self, value):
        self._price_id = value
    @property
    def price_policy_id(self):
        return self._price_policy_id

    @price_policy_id.setter
    def price_policy_id(self, value):
        self._price_policy_id = value
    @property
    def settle_type(self):
        return self._settle_type

    @settle_type.setter
    def settle_type(self, value):
        if isinstance(value, list):
            self._settle_type = list()
            for i in value:
                self._settle_type.append(i)
    @property
    def start_month(self):
        return self._start_month

    @start_month.setter
    def start_month(self, value):
        self._start_month = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.bill_invoice_link_statuses:
            if isinstance(self.bill_invoice_link_statuses, list):
                for i in range(0, len(self.bill_invoice_link_statuses)):
                    element = self.bill_invoice_link_statuses[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.bill_invoice_link_statuses[i] = element.to_alipay_dict()
            if hasattr(self.bill_invoice_link_statuses, 'to_alipay_dict'):
                params['bill_invoice_link_statuses'] = self.bill_invoice_link_statuses.to_alipay_dict()
            else:
                params['bill_invoice_link_statuses'] = self.bill_invoice_link_statuses
        if self.bill_types:
            if isinstance(self.bill_types, list):
                for i in range(0, len(self.bill_types)):
                    element = self.bill_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.bill_types[i] = element.to_alipay_dict()
            if hasattr(self.bill_types, 'to_alipay_dict'):
                params['bill_types'] = self.bill_types.to_alipay_dict()
            else:
                params['bill_types'] = self.bill_types
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.ccy:
            if hasattr(self.ccy, 'to_alipay_dict'):
                params['ccy'] = self.ccy.to_alipay_dict()
            else:
                params['ccy'] = self.ccy
        if self.end_month:
            if hasattr(self.end_month, 'to_alipay_dict'):
                params['end_month'] = self.end_month.to_alipay_dict()
            else:
                params['end_month'] = self.end_month
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.pay_statuses:
            if isinstance(self.pay_statuses, list):
                for i in range(0, len(self.pay_statuses)):
                    element = self.pay_statuses[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pay_statuses[i] = element.to_alipay_dict()
            if hasattr(self.pay_statuses, 'to_alipay_dict'):
                params['pay_statuses'] = self.pay_statuses.to_alipay_dict()
            else:
                params['pay_statuses'] = self.pay_statuses
        if self.pd_codes:
            if isinstance(self.pd_codes, list):
                for i in range(0, len(self.pd_codes)):
                    element = self.pd_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pd_codes[i] = element.to_alipay_dict()
            if hasattr(self.pd_codes, 'to_alipay_dict'):
                params['pd_codes'] = self.pd_codes.to_alipay_dict()
            else:
                params['pd_codes'] = self.pd_codes
        if self.price_id:
            if hasattr(self.price_id, 'to_alipay_dict'):
                params['price_id'] = self.price_id.to_alipay_dict()
            else:
                params['price_id'] = self.price_id
        if self.price_policy_id:
            if hasattr(self.price_policy_id, 'to_alipay_dict'):
                params['price_policy_id'] = self.price_policy_id.to_alipay_dict()
            else:
                params['price_policy_id'] = self.price_policy_id
        if self.settle_type:
            if isinstance(self.settle_type, list):
                for i in range(0, len(self.settle_type)):
                    element = self.settle_type[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.settle_type[i] = element.to_alipay_dict()
            if hasattr(self.settle_type, 'to_alipay_dict'):
                params['settle_type'] = self.settle_type.to_alipay_dict()
            else:
                params['settle_type'] = self.settle_type
        if self.start_month:
            if hasattr(self.start_month, 'to_alipay_dict'):
                params['start_month'] = self.start_month.to_alipay_dict()
            else:
                params['start_month'] = self.start_month
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncApbillCustviewBatchqueryModel()
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'bill_invoice_link_statuses' in d:
            o.bill_invoice_link_statuses = d['bill_invoice_link_statuses']
        if 'bill_types' in d:
            o.bill_types = d['bill_types']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'ccy' in d:
            o.ccy = d['ccy']
        if 'end_month' in d:
            o.end_month = d['end_month']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'pay_statuses' in d:
            o.pay_statuses = d['pay_statuses']
        if 'pd_codes' in d:
            o.pd_codes = d['pd_codes']
        if 'price_id' in d:
            o.price_id = d['price_id']
        if 'price_policy_id' in d:
            o.price_policy_id = d['price_policy_id']
        if 'settle_type' in d:
            o.settle_type = d['settle_type']
        if 'start_month' in d:
            o.start_month = d['start_month']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PageVisitDataResponse(object):

    def __init__(self):
        self._page_pv = None
        self._page_uv = None
        self._url = None

    @property
    def page_pv(self):
        return self._page_pv

    @page_pv.setter
    def page_pv(self, value):
        self._page_pv = value
    @property
    def page_uv(self):
        return self._page_uv

    @page_uv.setter
    def page_uv(self, value):
        self._page_uv = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.page_pv:
            if hasattr(self.page_pv, 'to_alipay_dict'):
                params['page_pv'] = self.page_pv.to_alipay_dict()
            else:
                params['page_pv'] = self.page_pv
        if self.page_uv:
            if hasattr(self.page_uv, 'to_alipay_dict'):
                params['page_uv'] = self.page_uv.to_alipay_dict()
            else:
                params['page_uv'] = self.page_uv
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PageVisitDataResponse()
        if 'page_pv' in d:
            o.page_pv = d['page_pv']
        if 'page_uv' in d:
            o.page_uv = d['page_uv']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingActivityAppBatchqueryModel(object):

    def __init__(self):
        self._activity_id = None
        self._merchant_access_mode = None
        self._merchant_id = None
        self._page_num = None
        self._page_size = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def merchant_access_mode(self):
        return self._merchant_access_mode

    @merchant_access_mode.setter
    def merchant_access_mode(self, value):
        self._merchant_access_mode = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.merchant_access_mode:
            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
            else:
                params['merchant_access_mode'] = self.merchant_access_mode
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityAppBatchqueryModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'merchant_access_mode' in d:
            o.merchant_access_mode = d['merchant_access_mode']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessParamsDTO(object):

    def __init__(self):
        self._actual_order_time = None
        self._campus_card = None
        self._card_type = None
        self._enterprise_pay_amount = None
        self._enterprise_pay_info = None
        self._good_taxes = None

    @property
    def actual_order_time(self):
        return self._actual_order_time

    @actual_order_time.setter
    def actual_order_time(self, value):
        self._actual_order_time = value
    @property
    def campus_card(self):
        return self._campus_card

    @campus_card.setter
    def campus_card(self, value):
        self._campus_card = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def enterprise_pay_amount(self):
        return self._enterprise_pay_amount

    @enterprise_pay_amount.setter
    def enterprise_pay_amount(self, value):
        self._enterprise_pay_amount = value
    @property
    def enterprise_pay_info(self):
        return self._enterprise_pay_info

    @enterprise_pay_info.setter
    def enterprise_pay_info(self, value):
        self._enterprise_pay_info = value
    @property
    def good_taxes(self):
        return self._good_taxes

    @good_taxes.setter
    def good_taxes(self, value):
        self._good_taxes = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_order_time:
            if hasattr(self.actual_order_time, 'to_alipay_dict'):
                params['actual_order_time'] = self.actual_order_time.to_alipay_dict()
            else:
                params['actual_order_time'] = self.actual_order_time
        if self.campus_card:
            if hasattr(self.campus_card, 'to_alipay_dict'):
                params['campus_card'] = self.campus_card.to_alipay_dict()
            else:
                params['campus_card'] = self.campus_card
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.enterprise_pay_amount:
            if hasattr(self.enterprise_pay_amount, 'to_alipay_dict'):
                params['enterprise_pay_amount'] = self.enterprise_pay_amount.to_alipay_dict()
            else:
                params['enterprise_pay_amount'] = self.enterprise_pay_amount
        if self.enterprise_pay_info:
            if hasattr(self.enterprise_pay_info, 'to_alipay_dict'):
                params['enterprise_pay_info'] = self.enterprise_pay_info.to_alipay_dict()
            else:
                params['enterprise_pay_info'] = self.enterprise_pay_info
        if self.good_taxes:
            if hasattr(self.good_taxes, 'to_alipay_dict'):
                params['good_taxes'] = self.good_taxes.to_alipay_dict()
            else:
                params['good_taxes'] = self.good_taxes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessParamsDTO()
        if 'actual_order_time' in d:
            o.actual_order_time = d['actual_order_time']
        if 'campus_card' in d:
            o.campus_card = d['campus_card']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'enterprise_pay_amount' in d:
            o.enterprise_pay_amount = d['enterprise_pay_amount']
        if 'enterprise_pay_info' in d:
            o.enterprise_pay_info = d['enterprise_pay_info']
        if 'good_taxes' in d:
            o.good_taxes = d['good_taxes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAmpeDeviceAddModel(object):

    def __init__(self):
        self._device_id_list = None
        self._model_id = None
        self._product_id = None

    @property
    def device_id_list(self):
        return self._device_id_list

    @device_id_list.setter
    def device_id_list(self, value):
        if isinstance(value, list):
            self._device_id_list = list()
            for i in value:
                self._device_id_list.append(i)
    @property
    def model_id(self):
        return self._model_id

    @model_id.setter
    def model_id(self, value):
        self._model_id = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id_list:
            if isinstance(self.device_id_list, list):
                for i in range(0, len(self.device_id_list)):
                    element = self.device_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_id_list[i] = element.to_alipay_dict()
            if hasattr(self.device_id_list, 'to_alipay_dict'):
                params['device_id_list'] = self.device_id_list.to_alipay_dict()
            else:
                params['device_id_list'] = self.device_id_list
        if self.model_id:
            if hasattr(self.model_id, 'to_alipay_dict'):
                params['model_id'] = self.model_id.to_alipay_dict()
            else:
                params['model_id'] = self.model_id
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAmpeDeviceAddModel()
        if 'device_id_list' in d:
            o.device_id_list = d['device_id_list']
        if 'model_id' in d:
            o.model_id = d['model_id']
        if 'product_id' in d:
            o.product_id = d['product_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GroupMemberDetail(object):

    def __init__(self):
        self._group_nick_name = None
        self._invite_id = None
        self._invite_open_id = None
        self._join_scene = None
        self._join_time = None
        self._open_id = None
        self._user_id = None

    @property
    def group_nick_name(self):
        return self._group_nick_name

    @group_nick_name.setter
    def group_nick_name(self, value):
        self._group_nick_name = value
    @property
    def invite_id(self):
        return self._invite_id

    @invite_id.setter
    def invite_id(self, value):
        self._invite_id = value
    @property
    def invite_open_id(self):
        return self._invite_open_id

    @invite_open_id.setter
    def invite_open_id(self, value):
        self._invite_open_id = value
    @property
    def join_scene(self):
        return self._join_scene

    @join_scene.setter
    def join_scene(self, value):
        self._join_scene = value
    @property
    def join_time(self):
        return self._join_time

    @join_time.setter
    def join_time(self, value):
        self._join_time = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.group_nick_name:
            if hasattr(self.group_nick_name, 'to_alipay_dict'):
                params['group_nick_name'] = self.group_nick_name.to_alipay_dict()
            else:
                params['group_nick_name'] = self.group_nick_name
        if self.invite_id:
            if hasattr(self.invite_id, 'to_alipay_dict'):
                params['invite_id'] = self.invite_id.to_alipay_dict()
            else:
                params['invite_id'] = self.invite_id
        if self.invite_open_id:
            if hasattr(self.invite_open_id, 'to_alipay_dict'):
                params['invite_open_id'] = self.invite_open_id.to_alipay_dict()
            else:
                params['invite_open_id'] = self.invite_open_id
        if self.join_scene:
            if hasattr(self.join_scene, 'to_alipay_dict'):
                params['join_scene'] = self.join_scene.to_alipay_dict()
            else:
                params['join_scene'] = self.join_scene
        if self.join_time:
            if hasattr(self.join_time, 'to_alipay_dict'):
                params['join_time'] = self.join_time.to_alipay_dict()
            else:
                params['join_time'] = self.join_time
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GroupMemberDetail()
        if 'group_nick_name' in d:
            o.group_nick_name = d['group_nick_name']
        if 'invite_id' in d:
            o.invite_id = d['invite_id']
        if 'invite_open_id' in d:
            o.invite_open_id = d['invite_open_id']
        if 'join_scene' in d:
            o.join_scene = d['join_scene']
        if 'join_time' in d:
            o.join_time = d['join_time']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MsgParams(object):

    def __init__(self):
        self._bill_amount = None
        self._company_name = None
        self._expire_days = None
        self._repay_date = None

    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def expire_days(self):
        return self._expire_days

    @expire_days.setter
    def expire_days(self, value):
        self._expire_days = value
    @property
    def repay_date(self):
        return self._repay_date

    @repay_date.setter
    def repay_date(self, value):
        self._repay_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_amount:
            if hasattr(self.bill_amount, 'to_alipay_dict'):
                params['bill_amount'] = self.bill_amount.to_alipay_dict()
            else:
                params['bill_amount'] = self.bill_amount
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.expire_days:
            if hasattr(self.expire_days, 'to_alipay_dict'):
                params['expire_days'] = self.expire_days.to_alipay_dict()
            else:
                params['expire_days'] = self.expire_days
        if self.repay_date:
            if hasattr(self.repay_date, 'to_alipay_dict'):
                params['repay_date'] = self.repay_date.to_alipay_dict()
            else:
                params['repay_date'] = self.repay_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MsgParams()
        if 'bill_amount' in d:
            o.bill_amount = d['bill_amount']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'expire_days' in d:
            o.expire_days = d['expire_days']
        if 'repay_date' in d:
            o.repay_date = d['repay_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncApinvoiceRcptQueryModel(object):

    def __init__(self):
        self._ar_no = None
        self._inst_id = None
        self._invoice_date_begin = None
        self._invoice_date_end = None
        self._invoice_mode = None
        self._ip_id = None
        self._ip_role_id = None
        self._out_biz_no = None
        self._out_biz_type = None
        self._product_code = None
        self._type = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_date_begin(self):
        return self._invoice_date_begin

    @invoice_date_begin.setter
    def invoice_date_begin(self, value):
        self._invoice_date_begin = value
    @property
    def invoice_date_end(self):
        return self._invoice_date_end

    @invoice_date_end.setter
    def invoice_date_end(self, value):
        self._invoice_date_end = value
    @property
    def invoice_mode(self):
        return self._invoice_mode

    @invoice_mode.setter
    def invoice_mode(self, value):
        self._invoice_mode = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_date_begin:
            if hasattr(self.invoice_date_begin, 'to_alipay_dict'):
                params['invoice_date_begin'] = self.invoice_date_begin.to_alipay_dict()
            else:
                params['invoice_date_begin'] = self.invoice_date_begin
        if self.invoice_date_end:
            if hasattr(self.invoice_date_end, 'to_alipay_dict'):
                params['invoice_date_end'] = self.invoice_date_end.to_alipay_dict()
            else:
                params['invoice_date_end'] = self.invoice_date_end
        if self.invoice_mode:
            if hasattr(self.invoice_mode, 'to_alipay_dict'):
                params['invoice_mode'] = self.invoice_mode.to_alipay_dict()
            else:
                params['invoice_mode'] = self.invoice_mode
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncApinvoiceRcptQueryModel()
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_date_begin' in d:
            o.invoice_date_begin = d['invoice_date_begin']
        if 'invoice_date_end' in d:
            o.invoice_date_end = d['invoice_date_end']
        if 'invoice_mode' in d:
            o.invoice_mode = d['invoice_mode']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosOrderKey import PosOrderKey


class KoubeiCateringOrderPayDisburseModel(object):

    def __init__(self):
        self._auth_code = None
        self._member_flag = None
        self._out_pay_no = None
        self._pos_order_key = None
        self._timeout = None
        self._total_amount = None
        self._undiscountable = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def member_flag(self):
        return self._member_flag

    @member_flag.setter
    def member_flag(self, value):
        self._member_flag = value
    @property
    def out_pay_no(self):
        return self._out_pay_no

    @out_pay_no.setter
    def out_pay_no(self, value):
        self._out_pay_no = value
    @property
    def pos_order_key(self):
        return self._pos_order_key

    @pos_order_key.setter
    def pos_order_key(self, value):
        if isinstance(value, PosOrderKey):
            self._pos_order_key = value
        else:
            self._pos_order_key = PosOrderKey.from_alipay_dict(value)
    @property
    def timeout(self):
        return self._timeout

    @timeout.setter
    def timeout(self, value):
        self._timeout = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def undiscountable(self):
        return self._undiscountable

    @undiscountable.setter
    def undiscountable(self, value):
        self._undiscountable = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.member_flag:
            if hasattr(self.member_flag, 'to_alipay_dict'):
                params['member_flag'] = self.member_flag.to_alipay_dict()
            else:
                params['member_flag'] = self.member_flag
        if self.out_pay_no:
            if hasattr(self.out_pay_no, 'to_alipay_dict'):
                params['out_pay_no'] = self.out_pay_no.to_alipay_dict()
            else:
                params['out_pay_no'] = self.out_pay_no
        if self.pos_order_key:
            if hasattr(self.pos_order_key, 'to_alipay_dict'):
                params['pos_order_key'] = self.pos_order_key.to_alipay_dict()
            else:
                params['pos_order_key'] = self.pos_order_key
        if self.timeout:
            if hasattr(self.timeout, 'to_alipay_dict'):
                params['timeout'] = self.timeout.to_alipay_dict()
            else:
                params['timeout'] = self.timeout
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.undiscountable:
            if hasattr(self.undiscountable, 'to_alipay_dict'):
                params['undiscountable'] = self.undiscountable.to_alipay_dict()
            else:
                params['undiscountable'] = self.undiscountable
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringOrderPayDisburseModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'member_flag' in d:
            o.member_flag = d['member_flag']
        if 'out_pay_no' in d:
            o.out_pay_no = d['out_pay_no']
        if 'pos_order_key' in d:
            o.pos_order_key = d['pos_order_key']
        if 'timeout' in d:
            o.timeout = d['timeout']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'undiscountable' in d:
            o.undiscountable = d['undiscountable']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ServiceInfo import ServiceInfo


class AlipayOpenAppAppcontentInternalQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppAppcontentInternalQueryResponse, self).__init__()
        self._page_num = None
        self._page_size = None
        self._service_list = None
        self._total = None

    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def service_list(self):
        return self._service_list

    @service_list.setter
    def service_list(self, value):
        if isinstance(value, list):
            self._service_list = list()
            for i in value:
                if isinstance(i, ServiceInfo):
                    self._service_list.append(i)
                else:
                    self._service_list.append(ServiceInfo.from_alipay_dict(i))
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppAppcontentInternalQueryResponse, self).parse_response_content(response_content)
        if 'page_num' in response:
            self.page_num = response['page_num']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'service_list' in response:
            self.service_list = response['service_list']
        if 'total' in response:
            self.total = response['total']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicThirdCustomerServiceModel(object):

    def __init__(self):
        self._channel_uid = None

    @property
    def channel_uid(self):
        return self._channel_uid

    @channel_uid.setter
    def channel_uid(self, value):
        self._channel_uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_uid:
            if hasattr(self.channel_uid, 'to_alipay_dict'):
                params['channel_uid'] = self.channel_uid.to_alipay_dict()
            else:
                params['channel_uid'] = self.channel_uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicThirdCustomerServiceModel()
        if 'channel_uid' in d:
            o.channel_uid = d['channel_uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Address(object):

    def __init__(self):
        self._city = None
        self._county = None
        self._detail = None
        self._province = None

    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def county(self):
        return self._county

    @county.setter
    def county(self, value):
        self._county = value
    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        self._detail = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value


    def to_alipay_dict(self):
        params = dict()
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.county:
            if hasattr(self.county, 'to_alipay_dict'):
                params['county'] = self.county.to_alipay_dict()
            else:
                params['county'] = self.county
        if self.detail:
            if hasattr(self.detail, 'to_alipay_dict'):
                params['detail'] = self.detail.to_alipay_dict()
            else:
                params['detail'] = self.detail
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Address()
        if 'city' in d:
            o.city = d['city']
        if 'county' in d:
            o.county = d['county']
        if 'detail' in d:
            o.detail = d['detail']
        if 'province' in d:
            o.province = d['province']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeBatchTransferQueryModel(object):

    def __init__(self):
        self._extend_params = None
        self._out_request_no = None
        self._settle_no = None

    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def settle_no(self):
        return self._settle_no

    @settle_no.setter
    def settle_no(self, value):
        self._settle_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.settle_no:
            if hasattr(self.settle_no, 'to_alipay_dict'):
                params['settle_no'] = self.settle_no.to_alipay_dict()
            else:
                params['settle_no'] = self.settle_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeBatchTransferQueryModel()
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'settle_no' in d:
            o.settle_no = d['settle_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenCertifyMerchantConfig(object):

    def __init__(self):
        self._auth_scope = None
        self._auth_type = None
        self._face_reserve_strategy = None
        self._facial_picture_level = None
        self._linked_merchant_app_id = None
        self._linked_merchant_logo_url = None
        self._linked_merchant_name = None
        self._out_put_facial_picture = None
        self._return_url = None

    @property
    def auth_scope(self):
        return self._auth_scope

    @auth_scope.setter
    def auth_scope(self, value):
        self._auth_scope = value
    @property
    def auth_type(self):
        return self._auth_type

    @auth_type.setter
    def auth_type(self, value):
        self._auth_type = value
    @property
    def face_reserve_strategy(self):
        return self._face_reserve_strategy

    @face_reserve_strategy.setter
    def face_reserve_strategy(self, value):
        self._face_reserve_strategy = value
    @property
    def facial_picture_level(self):
        return self._facial_picture_level

    @facial_picture_level.setter
    def facial_picture_level(self, value):
        self._facial_picture_level = value
    @property
    def linked_merchant_app_id(self):
        return self._linked_merchant_app_id

    @linked_merchant_app_id.setter
    def linked_merchant_app_id(self, value):
        self._linked_merchant_app_id = value
    @property
    def linked_merchant_logo_url(self):
        return self._linked_merchant_logo_url

    @linked_merchant_logo_url.setter
    def linked_merchant_logo_url(self, value):
        self._linked_merchant_logo_url = value
    @property
    def linked_merchant_name(self):
        return self._linked_merchant_name

    @linked_merchant_name.setter
    def linked_merchant_name(self, value):
        self._linked_merchant_name = value
    @property
    def out_put_facial_picture(self):
        return self._out_put_facial_picture

    @out_put_facial_picture.setter
    def out_put_facial_picture(self, value):
        self._out_put_facial_picture = value
    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_scope:
            if hasattr(self.auth_scope, 'to_alipay_dict'):
                params['auth_scope'] = self.auth_scope.to_alipay_dict()
            else:
                params['auth_scope'] = self.auth_scope
        if self.auth_type:
            if hasattr(self.auth_type, 'to_alipay_dict'):
                params['auth_type'] = self.auth_type.to_alipay_dict()
            else:
                params['auth_type'] = self.auth_type
        if self.face_reserve_strategy:
            if hasattr(self.face_reserve_strategy, 'to_alipay_dict'):
                params['face_reserve_strategy'] = self.face_reserve_strategy.to_alipay_dict()
            else:
                params['face_reserve_strategy'] = self.face_reserve_strategy
        if self.facial_picture_level:
            if hasattr(self.facial_picture_level, 'to_alipay_dict'):
                params['facial_picture_level'] = self.facial_picture_level.to_alipay_dict()
            else:
                params['facial_picture_level'] = self.facial_picture_level
        if self.linked_merchant_app_id:
            if hasattr(self.linked_merchant_app_id, 'to_alipay_dict'):
                params['linked_merchant_app_id'] = self.linked_merchant_app_id.to_alipay_dict()
            else:
                params['linked_merchant_app_id'] = self.linked_merchant_app_id
        if self.linked_merchant_logo_url:
            if hasattr(self.linked_merchant_logo_url, 'to_alipay_dict'):
                params['linked_merchant_logo_url'] = self.linked_merchant_logo_url.to_alipay_dict()
            else:
                params['linked_merchant_logo_url'] = self.linked_merchant_logo_url
        if self.linked_merchant_name:
            if hasattr(self.linked_merchant_name, 'to_alipay_dict'):
                params['linked_merchant_name'] = self.linked_merchant_name.to_alipay_dict()
            else:
                params['linked_merchant_name'] = self.linked_merchant_name
        if self.out_put_facial_picture:
            if hasattr(self.out_put_facial_picture, 'to_alipay_dict'):
                params['out_put_facial_picture'] = self.out_put_facial_picture.to_alipay_dict()
            else:
                params['out_put_facial_picture'] = self.out_put_facial_picture
        if self.return_url:
            if hasattr(self.return_url, 'to_alipay_dict'):
                params['return_url'] = self.return_url.to_alipay_dict()
            else:
                params['return_url'] = self.return_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenCertifyMerchantConfig()
        if 'auth_scope' in d:
            o.auth_scope = d['auth_scope']
        if 'auth_type' in d:
            o.auth_type = d['auth_type']
        if 'face_reserve_strategy' in d:
            o.face_reserve_strategy = d['face_reserve_strategy']
        if 'facial_picture_level' in d:
            o.facial_picture_level = d['facial_picture_level']
        if 'linked_merchant_app_id' in d:
            o.linked_merchant_app_id = d['linked_merchant_app_id']
        if 'linked_merchant_logo_url' in d:
            o.linked_merchant_logo_url = d['linked_merchant_logo_url']
        if 'linked_merchant_name' in d:
            o.linked_merchant_name = d['linked_merchant_name']
        if 'out_put_facial_picture' in d:
            o.out_put_facial_picture = d['out_put_facial_picture']
        if 'return_url' in d:
            o.return_url = d['return_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RiskDoc(object):

    def __init__(self):
        self._event_time = None
        self._source_doc_id = None
        self._source_doc_type = None
        self._summary = None
        self._title = None

    @property
    def event_time(self):
        return self._event_time

    @event_time.setter
    def event_time(self, value):
        self._event_time = value
    @property
    def source_doc_id(self):
        return self._source_doc_id

    @source_doc_id.setter
    def source_doc_id(self, value):
        self._source_doc_id = value
    @property
    def source_doc_type(self):
        return self._source_doc_type

    @source_doc_type.setter
    def source_doc_type(self, value):
        self._source_doc_type = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.event_time:
            if hasattr(self.event_time, 'to_alipay_dict'):
                params['event_time'] = self.event_time.to_alipay_dict()
            else:
                params['event_time'] = self.event_time
        if self.source_doc_id:
            if hasattr(self.source_doc_id, 'to_alipay_dict'):
                params['source_doc_id'] = self.source_doc_id.to_alipay_dict()
            else:
                params['source_doc_id'] = self.source_doc_id
        if self.source_doc_type:
            if hasattr(self.source_doc_type, 'to_alipay_dict'):
                params['source_doc_type'] = self.source_doc_type.to_alipay_dict()
            else:
                params['source_doc_type'] = self.source_doc_type
        if self.summary:
            if hasattr(self.summary, 'to_alipay_dict'):
                params['summary'] = self.summary.to_alipay_dict()
            else:
                params['summary'] = self.summary
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskDoc()
        if 'event_time' in d:
            o.event_time = d['event_time']
        if 'source_doc_id' in d:
            o.source_doc_id = d['source_doc_id']
        if 'source_doc_type' in d:
            o.source_doc_type = d['source_doc_type']
        if 'summary' in d:
            o.summary = d['summary']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GiftTemplateMetaInfo(object):

    def __init__(self):
        self._link = None
        self._memo = None
        self._type = None

    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GiftTemplateMetaInfo()
        if 'link' in d:
            o.link = d['link']
        if 'memo' in d:
            o.memo = d['memo']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SceneMarketingContent(object):

    def __init__(self):
        self._category = None
        self._icon = None
        self._image = None
        self._meaning = None
        self._meaning_desc = None
        self._tags = None
        self._tips = None
        self._title = None
        self._type = None
        self._url = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def meaning(self):
        return self._meaning

    @meaning.setter
    def meaning(self, value):
        self._meaning = value
    @property
    def meaning_desc(self):
        return self._meaning_desc

    @meaning_desc.setter
    def meaning_desc(self, value):
        self._meaning_desc = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        if isinstance(value, list):
            self._tags = list()
            for i in value:
                self._tags.append(i)
    @property
    def tips(self):
        return self._tips

    @tips.setter
    def tips(self, value):
        if isinstance(value, list):
            self._tips = list()
            for i in value:
                self._tips.append(i)
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.meaning:
            if hasattr(self.meaning, 'to_alipay_dict'):
                params['meaning'] = self.meaning.to_alipay_dict()
            else:
                params['meaning'] = self.meaning
        if self.meaning_desc:
            if hasattr(self.meaning_desc, 'to_alipay_dict'):
                params['meaning_desc'] = self.meaning_desc.to_alipay_dict()
            else:
                params['meaning_desc'] = self.meaning_desc
        if self.tags:
            if isinstance(self.tags, list):
                for i in range(0, len(self.tags)):
                    element = self.tags[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tags[i] = element.to_alipay_dict()
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.tips:
            if isinstance(self.tips, list):
                for i in range(0, len(self.tips)):
                    element = self.tips[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tips[i] = element.to_alipay_dict()
            if hasattr(self.tips, 'to_alipay_dict'):
                params['tips'] = self.tips.to_alipay_dict()
            else:
                params['tips'] = self.tips
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SceneMarketingContent()
        if 'category' in d:
            o.category = d['category']
        if 'icon' in d:
            o.icon = d['icon']
        if 'image' in d:
            o.image = d['image']
        if 'meaning' in d:
            o.meaning = d['meaning']
        if 'meaning_desc' in d:
            o.meaning_desc = d['meaning_desc']
        if 'tags' in d:
            o.tags = d['tags']
        if 'tips' in d:
            o.tips = d['tips']
        if 'title' in d:
            o.title = d['title']
        if 'type' in d:
            o.type = d['type']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeliveryInfo import DeliveryInfo
from alipay.aop.api.domain.DeviceApplyTemplate import DeviceApplyTemplate


class AntMerchantExpandIsvDeviceCreateModel(object):

    def __init__(self):
        self._biz_type = None
        self._channel_isv_pid = None
        self._delivery_info = None
        self._device_list = None
        self._operator_contact = None
        self._operator_name = None
        self._pid = None
        self._reason = None
        self._shop_id = None
        self._usage_detail = None
        self._usage_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def channel_isv_pid(self):
        return self._channel_isv_pid

    @channel_isv_pid.setter
    def channel_isv_pid(self, value):
        self._channel_isv_pid = value
    @property
    def delivery_info(self):
        return self._delivery_info

    @delivery_info.setter
    def delivery_info(self, value):
        if isinstance(value, DeliveryInfo):
            self._delivery_info = value
        else:
            self._delivery_info = DeliveryInfo.from_alipay_dict(value)
    @property
    def device_list(self):
        return self._device_list

    @device_list.setter
    def device_list(self, value):
        if isinstance(value, list):
            self._device_list = list()
            for i in value:
                if isinstance(i, DeviceApplyTemplate):
                    self._device_list.append(i)
                else:
                    self._device_list.append(DeviceApplyTemplate.from_alipay_dict(i))
    @property
    def operator_contact(self):
        return self._operator_contact

    @operator_contact.setter
    def operator_contact(self, value):
        self._operator_contact = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def usage_detail(self):
        return self._usage_detail

    @usage_detail.setter
    def usage_detail(self, value):
        self._usage_detail = value
    @property
    def usage_type(self):
        return self._usage_type

    @usage_type.setter
    def usage_type(self, value):
        self._usage_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.channel_isv_pid:
            if hasattr(self.channel_isv_pid, 'to_alipay_dict'):
                params['channel_isv_pid'] = self.channel_isv_pid.to_alipay_dict()
            else:
                params['channel_isv_pid'] = self.channel_isv_pid
        if self.delivery_info:
            if hasattr(self.delivery_info, 'to_alipay_dict'):
                params['delivery_info'] = self.delivery_info.to_alipay_dict()
            else:
                params['delivery_info'] = self.delivery_info
        if self.device_list:
            if isinstance(self.device_list, list):
                for i in range(0, len(self.device_list)):
                    element = self.device_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_list[i] = element.to_alipay_dict()
            if hasattr(self.device_list, 'to_alipay_dict'):
                params['device_list'] = self.device_list.to_alipay_dict()
            else:
                params['device_list'] = self.device_list
        if self.operator_contact:
            if hasattr(self.operator_contact, 'to_alipay_dict'):
                params['operator_contact'] = self.operator_contact.to_alipay_dict()
            else:
                params['operator_contact'] = self.operator_contact
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.usage_detail:
            if hasattr(self.usage_detail, 'to_alipay_dict'):
                params['usage_detail'] = self.usage_detail.to_alipay_dict()
            else:
                params['usage_detail'] = self.usage_detail
        if self.usage_type:
            if hasattr(self.usage_type, 'to_alipay_dict'):
                params['usage_type'] = self.usage_type.to_alipay_dict()
            else:
                params['usage_type'] = self.usage_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIsvDeviceCreateModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'channel_isv_pid' in d:
            o.channel_isv_pid = d['channel_isv_pid']
        if 'delivery_info' in d:
            o.delivery_info = d['delivery_info']
        if 'device_list' in d:
            o.device_list = d['device_list']
        if 'operator_contact' in d:
            o.operator_contact = d['operator_contact']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'pid' in d:
            o.pid = d['pid']
        if 'reason' in d:
            o.reason = d['reason']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'usage_detail' in d:
            o.usage_detail = d['usage_detail']
        if 'usage_type' in d:
            o.usage_type = d['usage_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPromorulecenterRuleAnalyzeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPromorulecenterRuleAnalyzeResponse, self).__init__()
        self._fail_condition_msg = None
        self._fail_condition_name = None
        self._result_code = None
        self._success = None
        self._triggered = None

    @property
    def fail_condition_msg(self):
        return self._fail_condition_msg

    @fail_condition_msg.setter
    def fail_condition_msg(self, value):
        self._fail_condition_msg = value
    @property
    def fail_condition_name(self):
        return self._fail_condition_name

    @fail_condition_name.setter
    def fail_condition_name(self, value):
        self._fail_condition_name = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def triggered(self):
        return self._triggered

    @triggered.setter
    def triggered(self, value):
        self._triggered = value

    def parse_response_content(self, response_content):
        response = super(AlipayPromorulecenterRuleAnalyzeResponse, self).parse_response_content(response_content)
        if 'fail_condition_msg' in response:
            self.fail_condition_msg = response['fail_condition_msg']
        if 'fail_condition_name' in response:
            self.fail_condition_name = response['fail_condition_name']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'success' in response:
            self.success = response['success']
        if 'triggered' in response:
            self.triggered = response['triggered']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceMedicalCardAuthQueryModel(object):

    def __init__(self):
        self._ins_code = None
        self._relation_type = None

    @property
    def ins_code(self):
        return self._ins_code

    @ins_code.setter
    def ins_code(self, value):
        self._ins_code = value
    @property
    def relation_type(self):
        return self._relation_type

    @relation_type.setter
    def relation_type(self, value):
        self._relation_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ins_code:
            if hasattr(self.ins_code, 'to_alipay_dict'):
                params['ins_code'] = self.ins_code.to_alipay_dict()
            else:
                params['ins_code'] = self.ins_code
        if self.relation_type:
            if hasattr(self.relation_type, 'to_alipay_dict'):
                params['relation_type'] = self.relation_type.to_alipay_dict()
            else:
                params['relation_type'] = self.relation_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceMedicalCardAuthQueryModel()
        if 'ins_code' in d:
            o.ins_code = d['ins_code']
        if 'relation_type' in d:
            o.relation_type = d['relation_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityDataNamelistSendModel(object):

    def __init__(self):
        self._bizname = None
        self._payload = None
        self._sysname = None

    @property
    def bizname(self):
        return self._bizname

    @bizname.setter
    def bizname(self, value):
        self._bizname = value
    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        self._payload = value
    @property
    def sysname(self):
        return self._sysname

    @sysname.setter
    def sysname(self, value):
        self._sysname = value


    def to_alipay_dict(self):
        params = dict()
        if self.bizname:
            if hasattr(self.bizname, 'to_alipay_dict'):
                params['bizname'] = self.bizname.to_alipay_dict()
            else:
                params['bizname'] = self.bizname
        if self.payload:
            if hasattr(self.payload, 'to_alipay_dict'):
                params['payload'] = self.payload.to_alipay_dict()
            else:
                params['payload'] = self.payload
        if self.sysname:
            if hasattr(self.sysname, 'to_alipay_dict'):
                params['sysname'] = self.sysname.to_alipay_dict()
            else:
                params['sysname'] = self.sysname
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityDataNamelistSendModel()
        if 'bizname' in d:
            o.bizname = d['bizname']
        if 'payload' in d:
            o.payload = d['payload']
        if 'sysname' in d:
            o.sysname = d['sysname']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiServindustryReservationLeadsModifyModel(object):

    def __init__(self):
        self._gmt_arrived = None
        self._gmt_reserve = None
        self._memo = None
        self._reservation_record_id = None
        self._status_mark = None

    @property
    def gmt_arrived(self):
        return self._gmt_arrived

    @gmt_arrived.setter
    def gmt_arrived(self, value):
        self._gmt_arrived = value
    @property
    def gmt_reserve(self):
        return self._gmt_reserve

    @gmt_reserve.setter
    def gmt_reserve(self, value):
        self._gmt_reserve = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def reservation_record_id(self):
        return self._reservation_record_id

    @reservation_record_id.setter
    def reservation_record_id(self, value):
        self._reservation_record_id = value
    @property
    def status_mark(self):
        return self._status_mark

    @status_mark.setter
    def status_mark(self, value):
        self._status_mark = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_arrived:
            if hasattr(self.gmt_arrived, 'to_alipay_dict'):
                params['gmt_arrived'] = self.gmt_arrived.to_alipay_dict()
            else:
                params['gmt_arrived'] = self.gmt_arrived
        if self.gmt_reserve:
            if hasattr(self.gmt_reserve, 'to_alipay_dict'):
                params['gmt_reserve'] = self.gmt_reserve.to_alipay_dict()
            else:
                params['gmt_reserve'] = self.gmt_reserve
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.reservation_record_id:
            if hasattr(self.reservation_record_id, 'to_alipay_dict'):
                params['reservation_record_id'] = self.reservation_record_id.to_alipay_dict()
            else:
                params['reservation_record_id'] = self.reservation_record_id
        if self.status_mark:
            if hasattr(self.status_mark, 'to_alipay_dict'):
                params['status_mark'] = self.status_mark.to_alipay_dict()
            else:
                params['status_mark'] = self.status_mark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryReservationLeadsModifyModel()
        if 'gmt_arrived' in d:
            o.gmt_arrived = d['gmt_arrived']
        if 'gmt_reserve' in d:
            o.gmt_reserve = d['gmt_reserve']
        if 'memo' in d:
            o.memo = d['memo']
        if 'reservation_record_id' in d:
            o.reservation_record_id = d['reservation_record_id']
        if 'status_mark' in d:
            o.status_mark = d['status_mark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AreaDetail(object):

    def __init__(self):
        self._area_code = None
        self._area_name = None
        self._area_pv = None
        self._area_uv = None

    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def area_pv(self):
        return self._area_pv

    @area_pv.setter
    def area_pv(self, value):
        self._area_pv = value
    @property
    def area_uv(self):
        return self._area_uv

    @area_uv.setter
    def area_uv(self, value):
        self._area_uv = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.area_pv:
            if hasattr(self.area_pv, 'to_alipay_dict'):
                params['area_pv'] = self.area_pv.to_alipay_dict()
            else:
                params['area_pv'] = self.area_pv
        if self.area_uv:
            if hasattr(self.area_uv, 'to_alipay_dict'):
                params['area_uv'] = self.area_uv.to_alipay_dict()
            else:
                params['area_uv'] = self.area_uv
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AreaDetail()
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'area_pv' in d:
            o.area_pv = d['area_pv']
        if 'area_uv' in d:
            o.area_uv = d['area_uv']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniAmpeCollectrightQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniAmpeCollectrightQueryResponse, self).__init__()
        self._can_collect = None

    @property
    def can_collect(self):
        return self._can_collect

    @can_collect.setter
    def can_collect(self, value):
        self._can_collect = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniAmpeCollectrightQueryResponse, self).parse_response_content(response_content)
        if 'can_collect' in response:
            self.can_collect = response['can_collect']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DialogueKeyWord(object):

    def __init__(self):
        self._from = None
        self._to = None

    @property
    def from(self):
        return self._from

    @from.setter
    def from(self, value):
        self._from = value
    @property
    def to(self):
        return self._to

    @to.setter
    def to(self, value):
        self._to = value


    def to_alipay_dict(self):
        params = dict()
        if self.from:
            if hasattr(self.from, 'to_alipay_dict'):
                params['from'] = self.from.to_alipay_dict()
            else:
                params['from'] = self.from
        if self.to:
            if hasattr(self.to, 'to_alipay_dict'):
                params['to'] = self.to.to_alipay_dict()
            else:
                params['to'] = self.to
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DialogueKeyWord()
        if 'from' in d:
            o.from = d['from']
        if 'to' in d:
            o.to = d['to']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsUnderwriteMutualPolicyBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsUnderwriteMutualPolicyBatchqueryResponse, self).__init__()
        self._plan_no = None
        self._policy_nos = None

    @property
    def plan_no(self):
        return self._plan_no

    @plan_no.setter
    def plan_no(self, value):
        self._plan_no = value
    @property
    def policy_nos(self):
        return self._policy_nos

    @policy_nos.setter
    def policy_nos(self, value):
        if isinstance(value, list):
            self._policy_nos = list()
            for i in value:
                self._policy_nos.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayInsUnderwriteMutualPolicyBatchqueryResponse, self).parse_response_content(response_content)
        if 'plan_no' in response:
            self.plan_no = response['plan_no']
        if 'policy_nos' in response:
            self.policy_nos = response['policy_nos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCustomerAuthMutualviewApplyModel(object):

    def __init__(self):
        self._biz_type = None
        self._callback_url = None
        self._ext_biz_param = None
        self._identity_param = None
        self._product_param = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def callback_url(self):
        return self._callback_url

    @callback_url.setter
    def callback_url(self, value):
        self._callback_url = value
    @property
    def ext_biz_param(self):
        return self._ext_biz_param

    @ext_biz_param.setter
    def ext_biz_param(self, value):
        self._ext_biz_param = value
    @property
    def identity_param(self):
        return self._identity_param

    @identity_param.setter
    def identity_param(self, value):
        self._identity_param = value
    @property
    def product_param(self):
        return self._product_param

    @product_param.setter
    def product_param(self, value):
        self._product_param = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.callback_url:
            if hasattr(self.callback_url, 'to_alipay_dict'):
                params['callback_url'] = self.callback_url.to_alipay_dict()
            else:
                params['callback_url'] = self.callback_url
        if self.ext_biz_param:
            if hasattr(self.ext_biz_param, 'to_alipay_dict'):
                params['ext_biz_param'] = self.ext_biz_param.to_alipay_dict()
            else:
                params['ext_biz_param'] = self.ext_biz_param
        if self.identity_param:
            if hasattr(self.identity_param, 'to_alipay_dict'):
                params['identity_param'] = self.identity_param.to_alipay_dict()
            else:
                params['identity_param'] = self.identity_param
        if self.product_param:
            if hasattr(self.product_param, 'to_alipay_dict'):
                params['product_param'] = self.product_param.to_alipay_dict()
            else:
                params['product_param'] = self.product_param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerAuthMutualviewApplyModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'callback_url' in d:
            o.callback_url = d['callback_url']
        if 'ext_biz_param' in d:
            o.ext_biz_param = d['ext_biz_param']
        if 'identity_param' in d:
            o.identity_param = d['identity_param']
        if 'product_param' in d:
            o.product_param = d['product_param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FinEquityInfo import FinEquityInfo
from alipay.aop.api.domain.FinUserInfo import FinUserInfo


class AntfortuneMarketingEquitystatusThirdpartModifyModel(object):

    def __init__(self):
        self._equity_code = None
        self._equity_info = None
        self._out_biz_no = None
        self._source = None
        self._status = None
        self._update_time = None
        self._user_info = None

    @property
    def equity_code(self):
        return self._equity_code

    @equity_code.setter
    def equity_code(self, value):
        self._equity_code = value
    @property
    def equity_info(self):
        return self._equity_info

    @equity_info.setter
    def equity_info(self, value):
        if isinstance(value, FinEquityInfo):
            self._equity_info = value
        else:
            self._equity_info = FinEquityInfo.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value
    @property
    def user_info(self):
        return self._user_info

    @user_info.setter
    def user_info(self, value):
        if isinstance(value, FinUserInfo):
            self._user_info = value
        else:
            self._user_info = FinUserInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.equity_code:
            if hasattr(self.equity_code, 'to_alipay_dict'):
                params['equity_code'] = self.equity_code.to_alipay_dict()
            else:
                params['equity_code'] = self.equity_code
        if self.equity_info:
            if hasattr(self.equity_info, 'to_alipay_dict'):
                params['equity_info'] = self.equity_info.to_alipay_dict()
            else:
                params['equity_info'] = self.equity_info
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.update_time:
            if hasattr(self.update_time, 'to_alipay_dict'):
                params['update_time'] = self.update_time.to_alipay_dict()
            else:
                params['update_time'] = self.update_time
        if self.user_info:
            if hasattr(self.user_info, 'to_alipay_dict'):
                params['user_info'] = self.user_info.to_alipay_dict()
            else:
                params['user_info'] = self.user_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneMarketingEquitystatusThirdpartModifyModel()
        if 'equity_code' in d:
            o.equity_code = d['equity_code']
        if 'equity_info' in d:
            o.equity_info = d['equity_info']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'source' in d:
            o.source = d['source']
        if 'status' in d:
            o.status = d['status']
        if 'update_time' in d:
            o.update_time = d['update_time']
        if 'user_info' in d:
            o.user_info = d['user_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.Data import Data


class AlipayMobileStdPublicFollowListResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMobileStdPublicFollowListResponse, self).__init__()
        self._count = None
        self._data = None
        self._next_alipay_user_id = None
        self._next_user_id = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        if isinstance(value, Data):
            self._data = value
        else:
            self._data = Data.from_alipay_dict(value)
    @property
    def next_alipay_user_id(self):
        return self._next_alipay_user_id

    @next_alipay_user_id.setter
    def next_alipay_user_id(self, value):
        self._next_alipay_user_id = value
    @property
    def next_user_id(self):
        return self._next_user_id

    @next_user_id.setter
    def next_user_id(self, value):
        self._next_user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMobileStdPublicFollowListResponse, self).parse_response_content(response_content)
        if 'count' in response:
            self.count = response['count']
        if 'data' in response:
            self.data = response['data']
        if 'next_alipay_user_id' in response:
            self.next_alipay_user_id = response['next_alipay_user_id']
        if 'next_user_id' in response:
            self.next_user_id = response['next_user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GPSLocationInfo(object):

    def __init__(self):
        self._accuracy = None
        self._direction = None
        self._height = None
        self._latitude = None
        self._longitude = None
        self._speed = None

    @property
    def accuracy(self):
        return self._accuracy

    @accuracy.setter
    def accuracy(self, value):
        self._accuracy = value
    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def speed(self):
        return self._speed

    @speed.setter
    def speed(self, value):
        self._speed = value


    def to_alipay_dict(self):
        params = dict()
        if self.accuracy:
            if hasattr(self.accuracy, 'to_alipay_dict'):
                params['accuracy'] = self.accuracy.to_alipay_dict()
            else:
                params['accuracy'] = self.accuracy
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.height:
            if hasattr(self.height, 'to_alipay_dict'):
                params['height'] = self.height.to_alipay_dict()
            else:
                params['height'] = self.height
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.speed:
            if hasattr(self.speed, 'to_alipay_dict'):
                params['speed'] = self.speed.to_alipay_dict()
            else:
                params['speed'] = self.speed
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GPSLocationInfo()
        if 'accuracy' in d:
            o.accuracy = d['accuracy']
        if 'direction' in d:
            o.direction = d['direction']
        if 'height' in d:
            o.height = d['height']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'speed' in d:
            o.speed = d['speed']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PointInstruction import PointInstruction


class AlipayCommerceYuntaskPointinstructionQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceYuntaskPointinstructionQueryResponse, self).__init__()
        self._data = None
        self._page = None
        self._page_size = None
        self._total_size = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        if isinstance(value, list):
            self._data = list()
            for i in value:
                if isinstance(i, PointInstruction):
                    self._data.append(i)
                else:
                    self._data.append(PointInstruction.from_alipay_dict(i))
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceYuntaskPointinstructionQueryResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'page' in response:
            self.page = response['page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncGfsettleprodInvoiceCancelModel(object):

    def __init__(self):
        self._invoice_id = None
        self._invoice_no = None
        self._operator = None
        self._operator_type = None
        self._settle_ip_role_id = None

    @property
    def invoice_id(self):
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, value):
        self._invoice_id = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def operator_type(self):
        return self._operator_type

    @operator_type.setter
    def operator_type(self, value):
        self._operator_type = value
    @property
    def settle_ip_role_id(self):
        return self._settle_ip_role_id

    @settle_ip_role_id.setter
    def settle_ip_role_id(self, value):
        self._settle_ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_id:
            if hasattr(self.invoice_id, 'to_alipay_dict'):
                params['invoice_id'] = self.invoice_id.to_alipay_dict()
            else:
                params['invoice_id'] = self.invoice_id
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.operator_type:
            if hasattr(self.operator_type, 'to_alipay_dict'):
                params['operator_type'] = self.operator_type.to_alipay_dict()
            else:
                params['operator_type'] = self.operator_type
        if self.settle_ip_role_id:
            if hasattr(self.settle_ip_role_id, 'to_alipay_dict'):
                params['settle_ip_role_id'] = self.settle_ip_role_id.to_alipay_dict()
            else:
                params['settle_ip_role_id'] = self.settle_ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodInvoiceCancelModel()
        if 'invoice_id' in d:
            o.invoice_id = d['invoice_id']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'operator' in d:
            o.operator = d['operator']
        if 'operator_type' in d:
            o.operator_type = d['operator_type']
        if 'settle_ip_role_id' in d:
            o.settle_ip_role_id = d['settle_ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAmpeMobileappBindModel(object):

    def __init__(self):
        self._app_sign = None
        self._mobile_app_id = None
        self._product_id_list = None
        self._scene_code = None

    @property
    def app_sign(self):
        return self._app_sign

    @app_sign.setter
    def app_sign(self, value):
        self._app_sign = value
    @property
    def mobile_app_id(self):
        return self._mobile_app_id

    @mobile_app_id.setter
    def mobile_app_id(self, value):
        self._mobile_app_id = value
    @property
    def product_id_list(self):
        return self._product_id_list

    @product_id_list.setter
    def product_id_list(self, value):
        if isinstance(value, list):
            self._product_id_list = list()
            for i in value:
                self._product_id_list.append(i)
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_sign:
            if hasattr(self.app_sign, 'to_alipay_dict'):
                params['app_sign'] = self.app_sign.to_alipay_dict()
            else:
                params['app_sign'] = self.app_sign
        if self.mobile_app_id:
            if hasattr(self.mobile_app_id, 'to_alipay_dict'):
                params['mobile_app_id'] = self.mobile_app_id.to_alipay_dict()
            else:
                params['mobile_app_id'] = self.mobile_app_id
        if self.product_id_list:
            if isinstance(self.product_id_list, list):
                for i in range(0, len(self.product_id_list)):
                    element = self.product_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_id_list[i] = element.to_alipay_dict()
            if hasattr(self.product_id_list, 'to_alipay_dict'):
                params['product_id_list'] = self.product_id_list.to_alipay_dict()
            else:
                params['product_id_list'] = self.product_id_list
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAmpeMobileappBindModel()
        if 'app_sign' in d:
            o.app_sign = d['app_sign']
        if 'mobile_app_id' in d:
            o.mobile_app_id = d['mobile_app_id']
        if 'product_id_list' in d:
            o.product_id_list = d['product_id_list']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataBillAccountlogQueryModel(object):

    def __init__(self):
        self._agreement_no = None
        self._agreement_product_code = None
        self._alipay_order_no = None
        self._bill_user_id = None
        self._end_time = None
        self._merchant_order_no = None
        self._page_no = None
        self._page_size = None
        self._start_time = None
        self._trans_code = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def agreement_product_code(self):
        return self._agreement_product_code

    @agreement_product_code.setter
    def agreement_product_code(self, value):
        self._agreement_product_code = value
    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def bill_user_id(self):
        return self._bill_user_id

    @bill_user_id.setter
    def bill_user_id(self, value):
        self._bill_user_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def trans_code(self):
        return self._trans_code

    @trans_code.setter
    def trans_code(self, value):
        self._trans_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.agreement_product_code:
            if hasattr(self.agreement_product_code, 'to_alipay_dict'):
                params['agreement_product_code'] = self.agreement_product_code.to_alipay_dict()
            else:
                params['agreement_product_code'] = self.agreement_product_code
        if self.alipay_order_no:
            if hasattr(self.alipay_order_no, 'to_alipay_dict'):
                params['alipay_order_no'] = self.alipay_order_no.to_alipay_dict()
            else:
                params['alipay_order_no'] = self.alipay_order_no
        if self.bill_user_id:
            if hasattr(self.bill_user_id, 'to_alipay_dict'):
                params['bill_user_id'] = self.bill_user_id.to_alipay_dict()
            else:
                params['bill_user_id'] = self.bill_user_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.trans_code:
            if hasattr(self.trans_code, 'to_alipay_dict'):
                params['trans_code'] = self.trans_code.to_alipay_dict()
            else:
                params['trans_code'] = self.trans_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataBillAccountlogQueryModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'agreement_product_code' in d:
            o.agreement_product_code = d['agreement_product_code']
        if 'alipay_order_no' in d:
            o.alipay_order_no = d['alipay_order_no']
        if 'bill_user_id' in d:
            o.bill_user_id = d['bill_user_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'trans_code' in d:
            o.trans_code = d['trans_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AccessParams import AccessParams
from alipay.aop.api.domain.MerchantCard import MerchantCard


class AntOcrTesConsultResponse(AlipayResponse):

    def __init__(self):
        super(AntOcrTesConsultResponse, self).__init__()
        self._hhgghfghj = None
        self._ppds = None
        self._test_3 = None

    @property
    def hhgghfghj(self):
        return self._hhgghfghj

    @hhgghfghj.setter
    def hhgghfghj(self, value):
        if isinstance(value, AccessParams):
            self._hhgghfghj = value
        else:
            self._hhgghfghj = AccessParams.from_alipay_dict(value)
    @property
    def ppds(self):
        return self._ppds

    @ppds.setter
    def ppds(self, value):
        self._ppds = value
    @property
    def test_3(self):
        return self._test_3

    @test_3.setter
    def test_3(self, value):
        if isinstance(value, MerchantCard):
            self._test_3 = value
        else:
            self._test_3 = MerchantCard.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AntOcrTesConsultResponse, self).parse_response_content(response_content)
        if 'hhgghfghj' in response:
            self.hhgghfghj = response['hhgghfghj']
        if 'ppds' in response:
            self.ppds = response['ppds']
        if 'test_3' in response:
            self.test_3 = response['test_3']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AdUserQualification import AdUserQualification


class AlipayCommerceTransportAdAduserqualificationBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportAdAduserqualificationBatchqueryResponse, self).__init__()
        self._ad_user_qualification = None

    @property
    def ad_user_qualification(self):
        return self._ad_user_qualification

    @ad_user_qualification.setter
    def ad_user_qualification(self, value):
        if isinstance(value, list):
            self._ad_user_qualification = list()
            for i in value:
                if isinstance(i, AdUserQualification):
                    self._ad_user_qualification.append(i)
                else:
                    self._ad_user_qualification.append(AdUserQualification.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportAdAduserqualificationBatchqueryResponse, self).parse_response_content(response_content)
        if 'ad_user_qualification' in response:
            self.ad_user_qualification = response['ad_user_qualification']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundCouponWufuAipictureMatchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponWufuAipictureMatchResponse, self).__init__()
        self._pass = None

    @property
    def pass(self):
        return self._pass

    @pass.setter
    def pass(self, value):
        self._pass = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponWufuAipictureMatchResponse, self).parse_response_content(response_content)
        if 'pass' in response:
            self.pass = response['pass']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicOdpsCrowdSyncModel(object):

    def __init__(self):
        self._channel = None
        self._crowd_name = None
        self._data_partition = None
        self._field_name = None
        self._group_id = None
        self._table_name = None
        self._user_type = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def crowd_name(self):
        return self._crowd_name

    @crowd_name.setter
    def crowd_name(self, value):
        self._crowd_name = value
    @property
    def data_partition(self):
        return self._data_partition

    @data_partition.setter
    def data_partition(self, value):
        if isinstance(value, list):
            self._data_partition = list()
            for i in value:
                self._data_partition.append(i)
    @property
    def field_name(self):
        return self._field_name

    @field_name.setter
    def field_name(self, value):
        self._field_name = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def table_name(self):
        return self._table_name

    @table_name.setter
    def table_name(self, value):
        self._table_name = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.crowd_name:
            if hasattr(self.crowd_name, 'to_alipay_dict'):
                params['crowd_name'] = self.crowd_name.to_alipay_dict()
            else:
                params['crowd_name'] = self.crowd_name
        if self.data_partition:
            if isinstance(self.data_partition, list):
                for i in range(0, len(self.data_partition)):
                    element = self.data_partition[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.data_partition[i] = element.to_alipay_dict()
            if hasattr(self.data_partition, 'to_alipay_dict'):
                params['data_partition'] = self.data_partition.to_alipay_dict()
            else:
                params['data_partition'] = self.data_partition
        if self.field_name:
            if hasattr(self.field_name, 'to_alipay_dict'):
                params['field_name'] = self.field_name.to_alipay_dict()
            else:
                params['field_name'] = self.field_name
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.table_name:
            if hasattr(self.table_name, 'to_alipay_dict'):
                params['table_name'] = self.table_name.to_alipay_dict()
            else:
                params['table_name'] = self.table_name
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicOdpsCrowdSyncModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'crowd_name' in d:
            o.crowd_name = d['crowd_name']
        if 'data_partition' in d:
            o.data_partition = d['data_partition']
        if 'field_name' in d:
            o.field_name = d['field_name']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'table_name' in d:
            o.table_name = d['table_name']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAliyunbenefitLogisticsCreateModel(object):

    def __init__(self):
        self._company_code = None
        self._lm_order_id = None
        self._logistics_status = None
        self._mail_no = None
        self._modified_time = None
        self._open_id = None
        self._order_status = None
        self._user_id = None

    @property
    def company_code(self):
        return self._company_code

    @company_code.setter
    def company_code(self, value):
        self._company_code = value
    @property
    def lm_order_id(self):
        return self._lm_order_id

    @lm_order_id.setter
    def lm_order_id(self, value):
        self._lm_order_id = value
    @property
    def logistics_status(self):
        return self._logistics_status

    @logistics_status.setter
    def logistics_status(self, value):
        self._logistics_status = value
    @property
    def mail_no(self):
        return self._mail_no

    @mail_no.setter
    def mail_no(self, value):
        self._mail_no = value
    @property
    def modified_time(self):
        return self._modified_time

    @modified_time.setter
    def modified_time(self, value):
        self._modified_time = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.company_code:
            if hasattr(self.company_code, 'to_alipay_dict'):
                params['company_code'] = self.company_code.to_alipay_dict()
            else:
                params['company_code'] = self.company_code
        if self.lm_order_id:
            if hasattr(self.lm_order_id, 'to_alipay_dict'):
                params['lm_order_id'] = self.lm_order_id.to_alipay_dict()
            else:
                params['lm_order_id'] = self.lm_order_id
        if self.logistics_status:
            if hasattr(self.logistics_status, 'to_alipay_dict'):
                params['logistics_status'] = self.logistics_status.to_alipay_dict()
            else:
                params['logistics_status'] = self.logistics_status
        if self.mail_no:
            if hasattr(self.mail_no, 'to_alipay_dict'):
                params['mail_no'] = self.mail_no.to_alipay_dict()
            else:
                params['mail_no'] = self.mail_no
        if self.modified_time:
            if hasattr(self.modified_time, 'to_alipay_dict'):
                params['modified_time'] = self.modified_time.to_alipay_dict()
            else:
                params['modified_time'] = self.modified_time
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAliyunbenefitLogisticsCreateModel()
        if 'company_code' in d:
            o.company_code = d['company_code']
        if 'lm_order_id' in d:
            o.lm_order_id = d['lm_order_id']
        if 'logistics_status' in d:
            o.logistics_status = d['logistics_status']
        if 'mail_no' in d:
            o.mail_no = d['mail_no']
        if 'modified_time' in d:
            o.modified_time = d['modified_time']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


